@@ -1,6 +1,7 @@
 /*
  * THE NEMESIS PROJECT
  * Copyright (C) 1999, 2000, 2001 Mark Grimes <obecian@packetninja.net>
+ * Portions copyright (C) 2001 Jeff Nathan <jeff@wwti.com>
  *
  * nemesis-dns.c (DNS Packet Injector)
  *
@@ -38,6 +39,7 @@ main(int argc, char **argv)
 	 putchar('\n');
 	 puts(TITLE " " VERSION);
 	 puts(CODERS);
+	 puts(NEWCODERS);
 	 putchar('\n');
 	 break;
       case 'k':
@@ -70,22 +72,18 @@ main(int argc, char **argv)
 	 device = optarg;
 	 break;
       case 'H':
-	 if (got_link) {
-	    sscanf(optarg, "%02X:%02X:%02X:%02X:%02X:%02X", &enet_tmp[0],
-		   &enet_tmp[1], &enet_tmp[2], &enet_tmp[3], &enet_tmp[4],
-		   &enet_tmp[5]);
-      for (i=0; i<6; i++)
-      	enet_src[i] = (u_char) enet_tmp[i];
-	 }
+         sscanf(optarg, "%02X:%02X:%02X:%02X:%02X:%02X", &enet_tmp[0],
+		&enet_tmp[1], &enet_tmp[2], &enet_tmp[3], &enet_tmp[4],
+		&enet_tmp[5]);
+         for (i=0; i<6; i++)
+      	    enet_src[i] = (u_char) enet_tmp[i];
 	 break;
       case 'M':
-	 if (got_link) {
-	    sscanf(optarg, "%02X:%02X:%02X:%02X:%02X:%02X", &enet_tmp[0],
-		   &enet_tmp[1], &enet_tmp[2], &enet_tmp[3], &enet_tmp[4],
-		   &enet_tmp[5]);
-      for (i=0; i<6; i++)
-      	enet_dst[i] = (u_char) enet_dst[i]; 
-	 }
+         sscanf(optarg, "%02X:%02X:%02X:%02X:%02X:%02X", &enet_tmp[0],
+		&enet_tmp[1], &enet_tmp[2], &enet_tmp[3], &enet_tmp[4],
+		&enet_tmp[5]);
+         for (i=0; i<6; i++)
+      	    enet_dst[i] = (u_char) enet_dst[i]; 
 	 break;
       case 'f':
 	 switch (*optarg) {
@@ -166,27 +164,34 @@ main(int argc, char **argv)
    argc -= optind;
    argv += optind;
 
+   /* sanity checks */
    if (source == 0 || dest == 0) {
       printf("Source and/or Destination Address Missing.\n");
       exit(1);
    }
+
+   if (got_link && !device) {
+      printf("Unspecified Device.\n");      
+      exit(-1);
+   }
+
+   if (got_link) {
+      if (enet_src[0] == NULL) {
+         e = libnet_get_hwaddr(l2, device, errbuf);
+         for (i=0; i<6; i++)
+            enet_src[i] = e->ether_addr_octet[i];
+         if (!e) {
+            fprintf(stderr, "cannot retrieve hardware address of %s: %s\n",
+		device, errbuf);
+         exit(1);
+         }
+      }          
+   }
+
    if (verbose) {
       if (got_link) {
-	 printf("[MAC]  ");
-      if (enet_src[0] == NULL) {
-        e = libnet_get_hwaddr(l2, device, errbuf);
-        for (i=0; i<6; i++)
-          enet_src[i] = e->ether_addr_octet[i];
-        if (!e) {   
-          fprintf(stderr, "cannot retrieve hardware address of %s: %s\n", device, errbuf);
-          exit(1);
-        }
-      }
-	 printf("%02X:%02X:%02X:%02X:%02X:%02X > %02X:%02X:%02X:%02X:%02X:%02X\n",
-		enet_src[0], enet_src[1], 
-		enet_src[2], enet_src[3], enet_src[4], enet_src[5],
-		enet_dst[0], enet_dst[1], enet_dst[2], enet_dst[3],
-		enet_dst[4], enet_dst[5]);
+         printf("[MAC]  ");
+         printf("%02X:%02X:%02X:%02X:%02X:%02X > %02X:%02X:%02X:%02X:%02X:%02X\n", enet_src[0], enet_src[1], enet_src[2], enet_src[3], enet_src[4], enet_src[5], enet_dst[0], enet_dst[1], enet_dst[2], enet_dst[3], enet_dst[4], enet_dst[5]);
       }
       printf("[Ports] %d > %d\n", sport, dport);
       printf("\n[# Questions] %d\n", num_q);
@@ -285,54 +290,56 @@ usage(char *arg)
    putchar('\n');
    puts(TITLE " " VERSION);
    puts(CODERS);
+   puts(NEWCODERS);
    putchar('\n');
 
    printf("DNS usage:\n  %s [-v] [options]\n\n", arg);
    printf("DNS options: \n"
-	  "  -q <# of Questions>\n"
-	  "  -W <# of Answer RRs>\n"
-	  "  -A <# of Authority RRs>\n"
-	  "  -i <# of Additional RRs>\n"
-	  "  -P <Payload File>\n"
-	  "  -k (Enable TCP transport)\n"
-	  "  (-v VERBOSE - packet struct to stdout)\n\n");
+          "  -q <# of Questions>\n"
+          "  -W <# of Answer RRs>\n"
+          "  -A <# of Authority RRs>\n"
+          "  -i <# of Additional RRs>\n"
+          "  -P <Payload File (Binary or ASCII)>\n"
+          "  -k (Enable TCP transport)\n"
+          "  (-v VERBOSE - packet struct to stdout)\n\n");
    printf("TCP options (-k): \n"
-	  "  [-x <Source Port>]\n"
-	  "  [-y <Destination Port>]\n"
-	  "  -f <TCP Flag Options>\n"
-	  "     -fS SYN, -fA ACK, -fR RST, -fP PSH, -fF FIN, -fU URG\n"
-	  "  -w <Window Size>\n"
-	  "  -s <SEQ Number>\n"
-	  "  -a <ACK Number>\n"
-	  "  -u <TCP Urgent Pointer>\n");
+          "  [-x <Source Port>]\n"
+          "  [-y <Destination Port>]\n"
+          "  -f <TCP Flag Options>\n"
+          "     -fS SYN, -fA ACK, -fR RST, -fP PSH, -fF FIN, -fU URG\n"
+          "  -w <Window Size>\n"
+          "  -s <SEQ Number>\n"
+          "  -a <ACK Number>\n"
+          "  -u <TCP Urgent Pointer>\n");
    printf("UDP options (no -k): \n"
-	  "  [-x <Source Port>]\n"
-	  "  [-y <Destination Port>]\n\n");
+          "  [-x <Source Port>]\n"
+          "  [-y <Destination Port>]\n\n");
    printf("IP options: \n"
-	  "  -S <Source IP Address>\n"
-	  "  -D <Destination IP Address>\n"
-	  "  -I <IP ID>\n"
-	  "  -T <IP TTL>\n"
-	  "  -t <IP tos>\n"
-	  "  -F <IP frag>\n"
-	  "  -O <IP Options>\n\n");
+          "  -S <Source IP Address>\n"
+          "  -D <Destination IP Address>\n"
+          "  -I <IP ID>\n"
+          "  -T <IP TTL>\n"
+          "  -t <IP tos>\n"
+          "  -F <IP frag>\n"
+          "  -O <IP Options>\n\n");
    printf("Data Link Options: \n"
-	  "  -d <Ethernet Device>\n"
-	  "  -H <Source MAC Address>\n"
-	  "  -M <Destination MAC Address>\n\n");
-   printf("You must define a Source, Destination and Protocol Options.\n");
+          "  -d <Ethernet Device>\n"
+          "  -H <Source MAC Address>\n"
+          "  -M <Destination MAC Address>\n\n");
+   printf("You must define a Source, Destination, Protocol & its dependant"
+	  "options.\n");
    exit(1);
 }
 
 void
 defaults()
 {
-   enet_src[0] = 0x02;
-   enet_src[1] = 0x0f;
-   enet_src[2] = 0x0a;
-   enet_src[3] = 0x0d;
-   enet_src[4] = 0x0e;
-   enet_src[5] = 0x0d;
+   enet_src[0] = NULL;
+   enet_src[1] = NULL;
+   enet_src[2] = NULL;
+   enet_src[3] = NULL;
+   enet_src[4] = NULL;
+   enet_src[5] = NULL;
 
    enet_dst[0] = 0x0d;
    enet_dst[1] = 0x0e;
