@@ -1,6 +1,7 @@
 /*
  * THE NEMESIS PROJECT
  * Copyright (C) 1999, 2000, 2001 Mark Grimes <obecian@packetninja.net>
+ * Portions copyright (C) 2001 Jeff Nathan <jeff@wwti.com>
  *
  * nemesis-igmp.h (IGMP Packet Injector)
  *
@@ -8,8 +9,9 @@
 
 
 #define TITLE "IGMP Packet Injection -=- The NEMESIS Project"
-#define VERSION "1.31"
+#define VERSION "1.32"
 #define CODERS "Copyright (C) 1999, 2000, 2001 Mark Grimes <obecian@packetninja.net>"
+#define NEWCODERS "Portions copyright (C) 2001 Jeff Nathan <jeff@wwti.com>"
 
 #include <stdio.h>
 #include <strings.h>
@@ -50,6 +52,10 @@ char           *device;		/* network device */
 
 int             verbose;	/* verbosity */
 
+char		errbuf[256];
+struct ether_addr *e;
+struct libnet_link_int *l2;
+
 int             buildigmp();
 
 void            hexdump(char *, int);
