@@ -1,6 +1,7 @@
 /*
  * THE NEMESIS PROJECT
  * Copyright (C) 1999, 2000, 2001 Mark Grimes <obecian@packetninja.net>
+ * Portions copyright (C) 2001 Jeff Nathan <jeff@wwti.com>
  *
  * nemesis-proto_dns.c (DNS Packet Generator)
  *
@@ -18,10 +19,6 @@ builddns()
    struct ipoption ipopt;
    char            errbuf[256];
 
-   if (got_link && !device) {
-      printf("Unspecified Device.\n");
-      exit(1);
-   }
    if (payload == NULL)
       payload_s = 0;
    else
